[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Xen-changelog] [xen-unstable] acm: Allow remove of labels from suspended domains.



# HG changeset patch
# User Keir Fraser <keir.fraser@xxxxxxxxxx>
# Date 1213000642 -3600
# Node ID 4eba2151d38b2071629de86beaf43593bdd5160b
# Parent  9126c09738da2dd6a2dee8e4e120496405708a85
acm: Allow remove of labels from suspended domains.
Signed-off-by: Stefan Berger <stefanb@xxxxxxxxxx>
---
 tools/python/xen/xend/XendDomainInfo.py |    4 ++--
 1 files changed, 2 insertions(+), 2 deletions(-)

diff -r 9126c09738da -r 4eba2151d38b tools/python/xen/xend/XendDomainInfo.py
--- a/tools/python/xen/xend/XendDomainInfo.py   Mon Jun 09 09:36:27 2008 +0100
+++ b/tools/python/xen/xend/XendDomainInfo.py   Mon Jun 09 09:37:22 2008 +0100
@@ -2891,9 +2891,9 @@ class XendDomainInfo:
                      DOM_STATES[state])
             return (-xsconstants.XSERR_VM_WRONG_STATE, "", "", 0)
 
         # Remove security label. Works only for halted domains
         if not seclab or seclab == "":
-            if state not in [ DOM_STATE_HALTED ]:
+            if state not in [ DOM_STATE_HALTED, DOM_STATE_SUSPENDED ]:
                 return (-xsconstants.XSERR_VM_WRONG_STATE, "", "", 0)
 
             if self.info.has_key('security_label'):
@@ -2891,9 +2891,9 @@ class XendDomainInfo:
             return (-xsconstants.XSERR_VM_WRONG_STATE, "", "", 0)
 
-        # Remove security label. Works only for halted domains
+        # Remove security label. Works only for halted or suspended domains
         if not seclab or seclab == "":

_______________________________________________
Xen-changelog mailing list
Xen-changelog@xxxxxxxxxxxxxxxxxxx
http://lists.xensource.com/xen-changelog


 


Rackspace

Lists.xenproject.org is hosted with RackSpace, monitoring our
servers 24x7x365 and backed by RackSpace's Fanatical Support®.